@@ -86,6 +86,7 @@ class SSHClient(object):
                 allow_agent=False,
                 timeout=self.__connect_timeout
             )
+            log.info(f"{self.__ip}:{self.__port} | ssh connect successfully.")
             return True
         except Exception as e:
             log.error(f"{self.__ip}:{self.__port} | failed to ssh connect. err msg is {str(e)}")
@@ -137,21 +138,14 @@ class SSHClient(object):
                 return_code = channel.recv_exit_status()
                 return ExecResult(return_code, output, stderr)
             else:
-                # stdin, stdout, stderr = self.__ssh.exec_command(cmd,timeout=timeout)
-                # exit_status = stdout.channel.recv_exit_status()
-                # std_output = stdout.read().decode()
-                # std_err = stderr.read().decode()
-                shell=self.__ssh.invoke_shell()
-                shell.send(f"{cmd}\n")
-                stdout=""
-                stderr=""
-                while shell.recv_ready():
-                    stdout+=shell.recv(1024).decode('utf-8', 'ignore')
-                while shell.recv_stderr_ready():
-                    stderr+=shell.recv_stderr(2024).decode('utf-8', 'ignore')
-                exit_status=shell.recv_exit_status()
+                ssh_tty=self.__ssh.invoke_shell()
+                stdin, stdout, stderr = self.__ssh.exec_command(cmd,timeout=timeout,get_pty=True)
+                exit_status = stdout.channel.recv_exit_status()
+                std_output = stdout.read().decode()
+                std_err = stderr.read().decode()
+
                 log.info(
-                    f" {self.__ip}:{self.__port} | successful to run cmd {cmd}, output is:{std_output}.")
+                    f" {self.__ip}:{self.__port} | successful to run cmd {cmd}, output is:{std_output} and stderr:{std_err}.")
                 return ExecResult(exit_status, std_output, std_err)
         except Exception as e:
             return ExecResult(1, "", str(e))
@@ -222,4 +216,3 @@ class SSHClient(object):
 
     def __del__(self):
         self.close()
-
